@@ -8,7 +8,7 @@ func (g *golang) string() string {
 	return g.language.string()
 }
 
-func (g *golang) init(props *properties, env environmentInfo) {
+func (g *golang) init(props properties, env environmentInfo) {
 	g.language = &language{
 		env:        env,
 		props:      props,
